OC.L10N.register(
    "core",
    {
    "Please select a file." : "Seletziona un'archìviu.",
    "File is too big" : "S'archìviu est tropu mannu",
    "The selected file is not an image." : "S'archìviu seletzionadu no est un'immàgine.",
    "The selected file cannot be read." : "S'archìviu seletzionadu non si podet lèghere.",
    "The file was uploaded" : "S'archìviu est istadu carrigadu",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "S'archìviu carrigadu superat sa diretiva upload_max_filesize in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "S'archìviu carrigadu superat sa diretiva MAX_FILE_SIZE ispetzificada in su mòdulu HTML",
    "The file was only partially uploaded" : "Isceti una parte de s'archìviu est carrigada",
    "No file was uploaded" : "Perunu archìviu carrigadu",
    "Missing a temporary folder" : "Mancat una cartella temporànea",
    "Could not write file to disk" : "No at fatu a iscrìere s'archìviu in su discu",
    "A PHP extension stopped the file upload" : "Un'estensione PHP at firmadu su carrigamentu de s'archìviu",
    "Invalid file provided" : "S'archìviu frunidu no est vàlidu",
    "No image or file provided" : "Peruna immàgine o archìviu",
    "Unknown filetype" : "Genia de archìviu disconnota",
    "An error occurred. Please contact your admin." : "B'at àpidu un'errore. Cuntata s'amministratzione tua.",
    "Invalid image" : "Immàgine non bàlida",
    "State token does not match" : "S'istadu de s'autenticadore non currispondet",
    "Invalid app password" : "Crae de aplicatzione non vàlida",
    "Could not complete login" : "Non s'est pòdida cumpletare s'intrada",
    "Your login token is invalid or has expired" : "S'atzessu cun autenticadore no est vàlidu o est iscadidu",
    "Login" : "Atzessu",
    "Password reset is disabled" : "Su riprìstinu de sa crae est disativadu",
    "Password is too long. Maximum allowed length is 469 characters." : "Sa crae est tropu longa. Sa longària màssima est de 469 caràteres.",
    "%s password reset" : "%s riprìstinu de sa crae",
    "Password reset" : "Riprìstinu de sa crae",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Incarca in su butone in fatu pro ripristinare sa crae. Si no as pedidu su riprìstinu de sa crae, non cunsìderes custu messàgiu.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Incarca in su ligòngiu in fatu pro ripristinare sa crae. Si no as pedidu su riprìstinu de sa crae, non cunsìderes custu messàgiu.",
    "Reset your password" : "Riprìstina sa crae",
    "Task not found" : "Faina no agatada!",
    "Internal error" : "Errore internu",
    "Not found" : "No agatadu",
    "No text to image provider is available" : "Nissunu servìtziu de cunversione de testu a immàgine a disponimentu",
    "Image not found" : "Immàgine no agatada",
    "No translation provider available" : "Nissunu servìtziu de tradutzione a disponimentu",
    "Could not detect language" : "Impossìbile rilevare sa lìngua",
    "Unable to translate" : "Impossìbile tradùere",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Passu de s'acontzu:",
    "Repair info:" : "Informatziones de s'acontzu:",
    "Repair warning:" : "Avisu de s'acontzu:",
    "Repair error:" : "Errore in s'acontzu:",
    "Nextcloud Server" : "Serbidore de Nextcloud",
    "Some of your link shares have been removed" : "Carchi ligòngiu de cumpartzidura tuo nch'est istadu bogadu",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pro un'errore de seguresa nch'amus dèpidu bogare carchi ligòngiu de cumpartzidura. Càstia su ligòngiu pro àteras informatziones.",
    "Learn more ↗" : "Àteras informatziones ↗",
    "Preparing update" : "Aprontende s'agiornamentu",
    "Turned on maintenance mode" : "Furriadu a modalidade de mantenidura",
    "Turned off maintenance mode" : "Modalidade de mantenidura disativada",
    "Maintenance mode is kept active" : "Sa modalidade de mantenidura abarrat ativa",
    "Updating database schema" : "Agiornende s'ischema de sa base de datos",
    "Updated database" : "Base de datos agionada",
    "Update app \"%s\" from App Store" : "Agiorna s'aplicatzione \"%s\" dae sa butega de is aplicatziones",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Averguende si s'ischema de sa base de datos de %s faghet a dd'agiornare (podet trigare segundu sa mannària de sa base de datos)",
    "Updated \"%1$s\" to %2$s" : "Agiornadu \"%1$s\" a %2$s",
    "Set log level to debug" : "Cunfigura su livellu de registratzione de currègere",
    "Reset log level" : "Reseta livellu de registratzione",
    "Starting code integrity check" : "Cumintzende su controllu de integridade de còdighe",
    "Finished code integrity check" : "Controllu de integridade de còdighe agabbadu",
    "%s (incompatible)" : "%s (non cumpatìbile)",
    "The following apps have been disabled: %s" : "Is aplicatziones in fatu sunt istadas disativadas: %s",
    "Already up to date" : "Giai agiornadu",
    "Unknown" : "Disconnotu",
    "unknown text" : "testu disconnotu",
    "Hello world!" : "Salude mundu!",
    "sunny" : "solianu",
    "Hello {name}, the weather is {weather}" : "Salude {name}, su tempus est {weather}",
    "Hello {name}" : "Salude {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Custos sunt is resurtados de sa chirca <script>avisu(1)</script></strong>",
    "new" : "nou",
    "_download %n file_::_download %n files_" : ["iscàrriga %n documentu","iscàrriga %narchìvios"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "S'agiornamentu est in cursu, lassende sa pàgina su protzessu si diat pòdere  suspèndere.",
    "Update to {version}" : "Agiorna a {version}",
    "An error occurred." : "B'at àpidu un'errore.",
    "Please reload the page." : "Torra a carrigare sa pàgina.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "S'agiornamentu est andadu male. Pro àteras informatziones <a href=\"{url}\">controlla sa publicatzione subra de custu </a> in su forum.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "S'agiornamentu no est andadu bene. Sinnala custu problema a sa <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade de Nextcloud </a>.",
    "Continue to {productName}" : "Sighi a {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["S'agiornamentu est andadu bene. Indiritzende·ti a {productName} intre %n segundu.","S'agiornamentu est andadu bene. Indiritzende·ti a {productName} intre %n segundos."],
    "Applications menu" : "Menù de aplicatziones",
    "Apps" : "Aplicatziones",
    "More apps" : "Àteras aplicatziones",
    "_{count} notification_::_{count} notifications_" : ["{count} notìfica","{count} notìficas"],
    "No" : "No",
    "Yes" : "Eja",
    "Failed to add the public link to your Nextcloud" : "No at fatu a agiùnghere su ligòngiu pùblicu in Nextcloud",
    "Create share" : "Crea cumpartzidura",
    "Custom date range" : "Perìodu personalizadu",
    "Pick start date" : "Sèbera una data de cumintzu",
    "Pick end date" : "Sèbera una data de acabbu",
    "Search in date range" : "Chirca in su perìodu de datas",
    "Searching …" : "Chirchende …",
    "Start typing to search" : "Cumintza a iscrìere pro chircare",
    "No matching results" : "Nissunu resurtadu",
    "Today" : "Oe ",
    "Last 7 days" : "Ùrtimas 7 dies",
    "Last 30 days" : "Ùrtimas 30 dies",
    "This year" : "Ocannu",
    "Last year" : "S'annu passadu",
    "Unified search" : "Chirca unificada",
    "Search apps, files, tags, messages" : "Chirca in is aplicatziones, archìvios, etichetas e messàgios",
    "Date" : "Data",
    "Search people" : "Chirca persones",
    "People" : "Gente",
    "Results" : "Resurtados",
    "Load more results" : "Càrriga àteros resurtados",
    "Search in" : "Chirca in",
    "Log in" : "Intra",
    "Logging in …" : "Intrende ...",
    "Log in to {productName}" : "Identìfica·ti in {productName}",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Amus agatadu tentativos meda de atzessu dae s'IP tuo. Duncas s'atzessu tuo imbeniente dd'as a pòdere fàghere intre 30 segundos.",
    "Account name or email" : "Nùmene de su contu o indiritzu de posta",
    "Server side authentication failed!" : "Autenticatzione de s'ala de su serbidore faddida!",
    "Please contact your administrator." : "Cuntata s'amministratzione.",
    "An internal error occurred." : "B'at àpidu un'errore internu.",
    "Please try again or contact your administrator." : "Torra a proare o cuntata s'amministratzione.",
    "Password" : "Crae",
    "Log in with a device" : "Autentica·ti cun unu dispositivu",
    "Your account is not setup for passwordless login." : "Su contu tuo no est fatu pro autenticatziones chene crae.",
    "Your connection is not secure" : "Sa connessione tua no est segura",
    "Passwordless authentication is only available over a secure connection." : "S'autenticatzione chene crae est a disponimentu isceti cun connessiones seguras.",
    "Browser not supported" : "Navigadore non suportadu",
    "Passwordless authentication is not supported in your browser." : "S'autenticatzione chene crae no est suportada in su navigadore tuo.",
    "Reset password" : "Riprìstina sa crae",
    "Back to login" : "Torra a s'autenticatzione",
    "Couldn't send reset email. Please contact your administrator." : "No at fatu a ripristinare sa posta eletrònica. Cuntata s'amministratzione.",
    "Password cannot be changed. Please contact your administrator." : "Sa crae non faghet a dda cambiare. Cuntata s'amministratzione.",
    "New password" : "Crae noa",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Is archìvios sunt critografados. Non ddoe at a èssere manera pro tènnere is datos a pustis de su riprìstinu de sa crae. Si tenes dudas, cuntata s'amministratzione in antis. A beru boles sighire?",
    "I know what I'm doing" : "Giai dd'isco ite so faghinde",
    "Resetting password" : "Ripristinende sa crae",
    "Schedule work & meetings, synced with all your devices." : "Programma atividades e addòbios, sincronizados cun is dispositivos tuos.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Mantene is collegas e is amistades tuas in unu logu chene mustrare is datos privados issoro.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicatzione de posta eletrònica simpre e integrada bene cun Archìvios, Cuntatos e Calendàriu.",
    "Recommended apps" : "Aplicatziones racumandadas",
    "Loading apps …" : "Carrighende aplicatziones ...",
    "Could not fetch list of apps from the App Store." : "No at fatu a recuperare sa lista dae sa butega de is aplicatziones.",
    "App download or installation failed" : "Iscarrigamentu de s'aplicatzione o installatzione faddida",
    "Cannot install this app because it is not compatible" : "Non faghet a installare custa aplicatzione ca no est cumpatìbile",
    "Cannot install this app" : "Non faghet a installare custa aplicatzione",
    "Skip" : "Brinca",
    "Installing apps …" : "Installende aplicatziones ...",
    "Install recommended apps" : "Installa is aplicatziones racumandadas",
    "Settings menu" : "Menù de cunfiguratzione",
    "Loading your contacts …" : "Carrighende is cuntatos...",
    "Looking for {term} …" : "Chirchende {term} …",
    "Search contacts" : "Chirca cuntatos",
    "Reset search" : "Riprìstina chirca",
    "Search contacts …" : "Chirca cuntatos ...",
    "Could not load your contacts" : "No at fatu a carrigare is cuntatos",
    "No contacts found" : "Perunu cuntatu agatadu",
    "Show all contacts" : "Mustra totu is cuntatos",
    "Install the Contacts app" : "Installa s'aplicatzione de is cuntatos",
    "Search" : "Chirca",
    "No results for {query}" : "Perunu resurtadu pro {query}",
    "Press Enter to start searching" : "Preme Enter pro cumintzare sa chirca",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Inserta {longàriaMinChirca} o prus caràteres pro chircare","Inserta·nche {minSearchLength} o prus caràteres pro chircare"],
    "An error occurred while searching for {type}" : "B'at àpidu un'errore in sa chirca de {type}",
    "Search for {name} only" : "Chirca pro {name} ebbia",
    "Loading more results …" : "Carrighende àteros resurtados ...",
    "Forgot password?" : "As ismentigadu sa crae?",
    "Back to login form" : "Torra a su formulàriu de identificatzione",
    "Back" : "A coa",
    "Login form is disabled." : "Su mòdulu de atzessu est disativadu.",
    "More actions" : "Àteras atziones",
    "Security warning" : "Avisu de seguresa",
    "Storage & database" : "Depòsitu e base de datos",
    "Data folder" : "Cartella de datos",
    "Install and activate additional PHP modules to choose other database types." : "Installa e ativa àteros mòdulos PHP pro seberare àteras genias de base de datos.",
    "For more details check out the documentation." : "Pro àteros detàllios controlla sa documentatzione.",
    "Performance warning" : "Avisu de atuatzione",
    "You chose SQLite as database." : "As seberadu SQLite comente base de datos.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite diat èssere impreadu isceti pro istàntzias mìnimas e de isvilupu. Pro sa produtzione cussigiamus un'àtera base de datos de palas.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Chi impreas clientes pro sa sincronizatzione de is archìvios, SQLite no est cussigiadu pro nudda.",
    "Database user" : "Utente base de datos",
    "Database password" : "Crae base de datos",
    "Database name" : "Nùmene base de datos",
    "Database tablespace" : "Logu de sa tauledda de sa base de datos",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Ispetzìfica su nùmeru de sa gianna aintru de su nùmene de su retzidore (p.e., retzidorelocale:5432).",
    "Database host" : "Retzidore de sa base de datos",
    "Installing …" : "Installende ...",
    "Install" : "Installa",
    "Need help?" : "Boles agiudu?",
    "See the documentation" : "Càstia sa documentatzione",
    "{name} version {version} and above" : "{name} versione {version} e superiores",
    "This browser is not supported" : "Custu navigadore no est cumpatìbile",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Su navigadore tuo no est cumpatìbile. Atualiza·ddu a una versione noa o càmbia a unu navigadore cumpatìbile.",
    "Continue with this unsupported browser" : "Abarra in custu navigadore non cumpatìbile",
    "Supported versions" : "Versiones cumpatìbiles",
    "Search {types} …" : "Chirca {types} …",
    "Choose {file}" : "Sèbera {file}",
    "Choose" : "Sèbera",
    "Copy to {target}" : "Còpia a {target}",
    "Copy" : "Còpia",
    "Move to {target}" : "Tràmuda a {target}",
    "Move" : "Tràmuda",
    "OK" : "AB",
    "read-only" : "letura sola",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} cunflitu de archìviu","{count} cunflitos de archìviu"],
    "One file conflict" : "Unu cunflitu de archìviu",
    "New Files" : "Archìvios noos",
    "Already existing files" : "Archìvios chi esistint giai",
    "Which files do you want to keep?" : "Cales archìvios boles mantènnere?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seletzionas ambas is versiones, s'archìviu copiadu at a tènnere unu nùmeru in agiunta a su nùmene.",
    "Cancel" : "Annulla",
    "Continue" : "Sighi",
    "(all selected)" : "(totu seletzionadu)",
    "({count} selected)" : "({count} seletzionadu)",
    "Error loading file exists template" : "Errore in su carrigamentu de su modellu de archìviu",
    "Saving …" : "Sarvende …",
    "seconds ago" : "segundos a immoe",
    "Connection to server lost" : "Connessione a su serbidore pèrdida",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Si seletzionas ambas is versiones, su documentu copiadu at a tènnere unu nùmeru in agiunta a su nùmene.","Problema in su carrigamentu de sa pàgina, torrende a carrigare intre %n segundos"],
    "Add to a project" : "Agiunghe a unu progetu",
    "Show details" : "Mustra detàllios",
    "Hide details" : "Cua detàllios",
    "Rename project" : "Torra a numenare su progetu",
    "Failed to rename the project" : "Impossìbile a numenare su progetu",
    "Failed to create a project" : "Impossìbile a creare unu progetu",
    "Failed to add the item to the project" : "No at fatu a agiunghere s'elementu a su progetu",
    "Connect items to a project to make them easier to find" : "Connete elementos a unu progetu pro chi siat prus fàtzile a ddos agatare",
    "Type to search for existing projects" : "Iscrie pro chircare is progetos chi ddoe sunt giai",
    "New in" : "Prima borta in",
    "View changelog" : "Càstia su registru de is càmbios",
    "No action available" : "Peruna atzione a disponimentu",
    "Error fetching contact actions" : "Errore in su recùperu de is atziones de cuntatu",
    "Close \"{dialogTitle}\" dialog" : "Serra su cuadru de diàlogu \"{dialogTitle}\"",
    "Personal" : "Personale",
    "Accounts" : "Accounts",
    "Admin" : "Amministratzione",
    "Help" : "Agiudu",
    "Access forbidden" : "Atzessu proibidu",
    "Back to %s" : "A coa a %s",
    "Page not found" : "Pàgina no agatada",
    "Too many requests" : "Tropu dimandas",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Tropu rechestas sunt arribadas dae sa rete tua. Torra a proare prus a tardu o cuntata s'amministradore tuo chi ddoe at un'errore.",
    "Error" : "Errore",
    "Internal Server Error" : "Errore serbidore internu",
    "The server was unable to complete your request." : "Su serbidore no at pòdidu cumpletare sa rechesta tua.",
    "If this happens again, please send the technical details below to the server administrator." : "Si torrat a capitare, imbia is detàllios tècnicos in bàsciu a s'amministratzione de su serbidore.",
    "More details can be found in the server log." : "S'ant a agatare àteros detàllios in su registru de su serbidore.",
    "Technical details" : "Detàllios tècnicos",
    "Remote Address: %s" : "Indiritzu remotu: %s",
    "Request ID: %s" : "Rechesta ID: %s",
    "Type: %s" : "Genia: %s",
    "Code: %s" : "Còdighe: %s",
    "Message: %s" : "Messàgiu: %s",
    "File: %s" : "Archìviu: %s",
    "Line: %s" : "Lìnia: %s",
    "Trace" : "Arrasta",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Paret chi ses chirchende de torrare a installare Nextcloud. In cada manera, mancat s'archìviu CAN_INSTALL in sa cartella de cunfiguratzione. Crea s'archìviu CAN_INSTALL in sa cartella de cunfiguratzione pro sighire.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "No at fatu a nche bogare CAN_INSTALL dae sa cartella de cunfiguratzione. Boga custu archìviu a manu.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Custa aplicatzione rechedet JavaScript pro un'operatzione curreta. {linkstart} Ativa JavaScript{linkend} e torra a carrigare sa pàgina.",
    "Skip to main content" : "Brinca a su cuntenutu printzipale",
    "Skip to navigation of app" : "Brinca a sa navigatzione de s'aplicatzione",
    "Go to %s" : "Bae a %s",
    "Get your own free account" : "Otene su contu tuo a gratis",
    "Connect to your account" : "Connete·ti a su contu tuo",
    "Please log in before granting %1$s access to your %2$s account." : "Faghe s'atzessu prima de permìtere a %1$s de intrare a su contu tuo de %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si non ses chirchende de cunfigurare unu dispositivu o un'aplicatzione noa, un'àtera persone est proende a si fàghere dare atzessu a is datos tuos. In custu casu, non sigas e cuntata s'amministratzione de su sistema tuo.",
    "App password" : "Crae de s'aplicatzione",
    "Grant access" : "Dona atzessu",
    "Alternative log in using app password" : "Identificatzione alternativa cun crae de s'aplicatzione",
    "Account access" : "Atzessu a su contu",
    "You are about to grant %1$s access to your %2$s account." : "Ses acanta de donare %1$s atzessu a su contu %2$s tuo.",
    "Account connected" : "Contu collegadu",
    "Your client should now be connected!" : "Su cliente tuo immoe diat dèpere èssere collegadu!",
    "You can close this window." : "Podes serrare custa ventana",
    "Previous" : "Pretzedente",
    "This share is password-protected" : "Custa cumpartzidura est amparada dae una crae",
    "Email address" : "Indiritzu de posta eletrònica",
    "Password sent!" : "Crae imbiada.",
    "Two-factor authentication" : "Autenticatzione a duos fatores",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Su megioru de seguresa est ativadu in su contu tuo. Sèbera unu segundu fatore pro s'autenticatzione:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "No at fatu a carriggare a su mancu unu de is mètodos de autenticatzione a duos fatores ativados. Cuntata s'amministratzione.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "S'est imposta s'autenticatzione a duos fatores ma non s'est cunfigurada in su contu tuo. Cuntata s'amministratzione si boles agiudu.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "S'est imposta s'autenticatzione a duos fatores ma non s'est cunfigurada in su contu tuo. Sighi pro impostare s'autenticatzione a duos fatores.",
    "Set up two-factor authentication" : "Cunfigura s'autenticatzione a duos fatores",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "S'est imposta s'autenticatzione a duos fatores ma non s'est cunfigurada in su contu tuo. Pro intrare imprea unu de is còdighes pro sa còpia de seguresa o cuntata s'amministratzione.",
    "Use backup code" : "Imprea su còdighe de sa còpia de seguresa",
    "Cancel login" : "Annulla atzessu",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "S'est impostu unu megioru de seguresa in su contu tuo. Sèbera su frunidore chi boles cunfigurare:",
    "Error while validating your second factor" : "Errore in sa validatzione de su seguntu fatore tuo",
    "Access through untrusted domain" : "Atzessu cun domìniu non seguru",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Àteras informatziones pro sa cunfiguratzione ddas podes agatare in sa %1$sdocumentatzione%2$s.",
    "App update required" : "Agiornamentu de aplicatzione rechertu",
    "%1$s will be updated to version %2$s" : "%1$s at a èssere agiornada a sa versione %2$s",
    "The following apps will be updated:" : "Is aplicatziones in fatu ant a èssere agiornadas:",
    "These incompatible apps will be disabled:" : "Custas aplicatziones non cumpatìbiles ant a èssere disativadas:",
    "The theme %s has been disabled." : "Su tema %s est istadu disativadu.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Prima de sighire, assegura·ti ca sa base de datos, sa cartella de cunfiguratzione e cussa de is datos tenent una còpia de seguresa.",
    "Start update" : "Cumintza agiornamentu",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Pro evitare pasadas cun installatziones mannas, podes dare su cumandu in fatu dae sa cartella de installatzione:",
    "Detailed logs" : "Registros detalliados",
    "Update needed" : "Tocat de agiornare",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pro agiudos, càstia sa  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentatzione</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Giai dd'isco ca chi sigu cun s'agiornamentu via internet UI ddoe at s'arriscu chi sa rechesta arribet a una pasada e podet causare sa pèrdida de is datos, ma tèngio una còpia de seguresa e isco comente recuperare s'istàntzia in casu de errore.",
    "Upgrade via web on my own risk" : "Agiorna via web suta responsabilidade mia",
    "Maintenance mode" : "Modalidade de mantenidura",
    "This %s instance is currently in maintenance mode, which may take a while." : "Immoe custa istàntzia de %s est in modalidade de mantenidura, e podet trigare unu pagu.",
    "This page will refresh itself when the instance is available again." : "Custa pàgina s'at a atualizare cando s'istàntzia at a èssere torra a disponimentu.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Cuntata s'amministratzione de sistema si custu messàgiu abarrat o torrat a cumpàrrere.",
    "No temporary profile picture available, try again" : "Peruna foto de profilu temporànea a disponimentu, torra a proare",
    "No crop data provided" : "Perunu datu frunidu",
    "No valid crop data provided" : "Perunu datu vàlidu frunidu",
    "Crop is not square" : "Su retàlliu no est a iscuadra",
    "Error occurred while checking server setup" : "Ddoe at àpidu un'errore in su controllu de sa cunfiguratzione de su serbidore",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Pro àteros detàllios controlla sa {linkstart}documentatzione ↗{linkend}.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Tzarradas, video mutidas, cumpartzidura de s'ischermu, reuniones in lìnia e vìdeo-cunferèntzias – in su navigadore tuo e cun aplicatziones mòbiles.",
    "Edit Profile" : "Modìfica su profilu",
    "The headline and about sections will show up here" : "Is setziones de tìtulu e informatziones ant a èssere ammustradas inoghe",
    "Very weak password" : "Crae dèbile meda",
    "Weak password" : "Crae dèbile",
    "So-so password" : "Crae aici aici",
    "Good password" : "Crae bona",
    "Strong password" : "Crae bona a beru",
    "Non-existing tag #{tag}" : "S'eticheta no esistit #{tag}",
    "Restricted" : "Limitadu",
    "Invisible" : "Invisìbile",
    "Delete" : "Cantzella",
    "Rename" : "Torra a numenare",
    "Collaborative tags" : "Etichetas collaborativas",
    "No tags found" : "Peruna eticheta agatada",
    "Profile not found" : "Profilu no agatadu",
    "The profile does not exist." : "Su profilu no esistit.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Is cartellas de datos e is archìvios tuos fortzis sunt atzessìbiles dae s'internet ca s'archìviu .htaccess no est funtzionende.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pro informatziones subra de comente cunfigurare su serbidore tuo, càstia in sa <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentatzione</a>.",
    "Show password" : "Mustra crae",
    "Toggle password visibility" : "Càmbia sa visibilidade de sa crae",
    "Configure the database" : "Cunfigura sa base de datos",
    "Only %s is available." : "%s isceti est a disponimentu."
},
"nplurals=2; plural=(n != 1);");
